<?php

return array(
    'number.decimals_separator' => '.',
    'number.thousands_separator' => ',',
    'None' => '无',
    'Edit' => '编辑',
    'Remove' => '移除',
    'Yes' => '是',
    'No' => '否',
    'cancel' => '取消',
    'or' => '或者',
    'Yellow' => '黄色',
    'Blue' => '蓝色',
    'Green' => '绿色',
    'Purple' => '紫色',
    'Red' => '红色',
    'Orange' => '橘色',
    'Grey' => '灰色',
    'Brown' => '褐色',
    'Deep Orange' => '橘红色',
    'Dark Grey' => '深灰色',
    'Pink' => '粉红色',
    'Teal' => '蓝绿色',
    'Cyan' => '青色',
    'Lime' => '黄绿色',
    'Light Green' => '浅绿色',
    'Amber' => '黄褐色',
    'Save' => '保存',
    'Login' => '登录',
    'Official website:' => '官方网站：',
    'Unassigned' => '未指派',
    'View this task' => '查看该任务',
    'Remove user' => '移除用户',
    'Do you really want to remove this user: "%s"?' => '确定要删除用户"%s"吗？',
    'All users' => '所有用户',
    'Username' => '用户名',
    'Password' => '密码',
    'Administrator' => '超级管理员',
    'Sign in' => '登录',
    'Users' => '用户',
    'Forbidden' => '禁止',
    'Access Forbidden' => '禁止进入',
    'Edit user' => '修改用户',
    'Logout' => '退出',
    'Bad username or password' => '用户名或密码错误',
    'Edit project' => '修改项目',
    'Name' => '名称',
    'Projects' => '项目',
    'No project' => '无项目',
    'Project' => '项目',
    'Status' => '状态',
    'Tasks' => '任务',
    'Board' => '看板',
    'Actions' => '动作',
    'Inactive' => '未激活',
    'Active' => '激活',
    'Unable to update this board.' => '无法更新该看板。',
    'Disable' => '停用',
    'Enable' => '启用',
    'New project' => '新建团队项目',
    'Do you really want to remove this project: "%s"?' => '确定要移除项目"%s"吗？',
    'Remove project' => '移除项目',
    'Edit the board for "%s"' => '为"%s"修改看板',
    'Add a new column' => '添加新栏目',
    'Title' => '标题',
    'Assigned to %s' => '指派给 %s',
    'Remove a column' => '移除一个栏目',
    'Unable to remove this column.' => '无法移除该栏目。',
    'Do you really want to remove this column: "%s"?' => '确定要移除栏目"%s"吗？',
    'Settings' => '设置',
    'Application settings' => '应用设置',
    'Language' => '语言',
    'Webhook token:' => '页面钩子令牌：',
    'API token:' => 'API 令牌：',
    'Database size:' => '数据库大小：',
    'Download the database' => '下载数据库',
    'Optimize the database' => '优化数据库',
    '(VACUUM command)' => '(VACUUM 指令)',
    '(Gzip compressed Sqlite file)' => '(用Gzip压缩的Sqlite文件)',
    'Close a task' => '关闭一个任务',
    'Column' => '栏目',
    'Color' => '颜色',
    'Assignee' => '指派给',
    'Create another task' => '创建另一个任务',
    'New task' => '新建任务',
    'Open a task' => '开启一个任务',
    'Do you really want to open this task: "%s"?' => '你确定要开这个任务吗？"%s"',
    'Back to the board' => '回到看板',
    'There is nobody assigned' => '当前无人被指派',
    'Column on the board:' => '看板上的栏目：',
    'Close this task' => '关闭该任务',
    'Open this task' => '开启该任务',
    'There is no description.' => '当前没有描述。',
    'Add a new task' => '添加新任务',
    'The username is required' => '需要用户名',
    'The maximum length is %d characters' => '最长%d个英文字符',
    'The minimum length is %d characters' => '最短%d个英文字符',
    'The password is required' => '需要密码',
    'This value must be an integer' => '该值必须为整数',
    'The username must be unique' => '用户名必须唯一',
    'The user id is required' => '用户id是必须的',
    'Passwords don\'t match' => '密码不匹配',
    'The confirmation is required' => '需要确认',
    'The project is required' => '需要指定项目',
    'The id is required' => '需要指定id',
    'The project id is required' => '需要指定项目id',
    'The project name is required' => '需要指定项目名称',
    'The title is required' => '需要指定标题',
    'Settings saved successfully.' => '设置成功保存。',
    'Unable to save your settings.' => '无法保存你的设置。',
    'Database optimization done.' => '数据库优化完成。',
    'Your project has been created successfully.' => '您的项目已经成功创建。',
    'Unable to create your project.' => '无法为您创建项目。',
    'Project updated successfully.' => '成功更新项目。',
    'Unable to update this project.' => '无法更新该项目。',
    'Unable to remove this project.' => '无法移除该项目。',
    'Project removed successfully.' => '成功移除项目。',
    'Project activated successfully.' => '项目成功激活。',
    'Unable to activate this project.' => '无法激活该项目。',
    'Project disabled successfully.' => '成功停用项目。',
    'Unable to disable this project.' => '无法停用该项目。',
    'Unable to open this task.' => '无法开启该任务。',
    'Task opened successfully.' => '任务开启成功。',
    'Unable to close this task.' => '无法关闭该任务。',
    'Task closed successfully.' => '成功关闭任务。',
    'Unable to update your task.' => '无法更新您的任务。',
    'Task updated successfully.' => '成功更新任务。',
    'Unable to create your task.' => '无法为您创建任务。',
    'Task created successfully.' => '成功创建任务。',
    'User created successfully.' => '成功创建用户。',
    'Unable to create your user.' => '无法创建用户。',
    'User updated successfully.' => '成功更新用户。',
    'User removed successfully.' => '成功移除用户。',
    'Unable to remove this user.' => '无法移除该用户。',
    'Board updated successfully.' => '看板成功更新。',
    'Ready' => '预备',
    'Backlog' => '待办',
    'Work in progress' => '进行中',
    'Done' => '完成',
    'Application version:' => '应用程序版本：',
    'Id' => '编号',
    'Public link' => '公开链接',
    'Timezone' => '时区',
    'Sorry, I didn\'t find this information in my database!' => '抱歉，无法在数据库中找到该信息！',
    'Page not found' => '页面未找到',
    'Complexity' => '复杂度',
    'Task limit' => '任务限制',
    'Task count' => '任务数',
    'User' => '用户',
    'Comments' => '评论',
    'Comment is required' => '评论不能为空',
    'Comment added successfully.' => '评论成功添加。',
    'Unable to create your comment.' => '无法创建评论。',
    'Due Date' => '到期时间',
    'Invalid date' => '无效日期',
    'Automatic actions' => '自动动作',
    'Your automatic action has been created successfully.' => '您的自动动作已成功创建',
    'Unable to create your automatic action.' => '无法为您创建自动动作。',
    'Remove an action' => '移除一个动作。',
    'Unable to remove this action.' => '无法移除该动作',
    'Action removed successfully.' => '成功移除动作。',
    'Automatic actions for the project "%s"' => '项目"%s"的自动动作',
    'Add an action' => '添加动作',
    'Event name' => '事件名称',
    'Action' => '动作',
    'Event' => '事件',
    'When the selected event occurs execute the corresponding action.' => '当所选事件发生时执行相应动作。',
    'Next step' => '下一步',
    'Define action parameters' => '定义动作参数',
    'Do you really want to remove this action: "%s"?' => '确定要移除动作"%s"吗？',
    'Remove an automatic action' => '移除一个自动动作',
    'Assign the task to a specific user' => '将该任务指派给一个用户',
    'Assign the task to the person who does the action' => '将任务指派给产生该动作的用户',
    'Duplicate the task to another project' => '复制该任务到另一项目',
    'Move a task to another column' => '移动任务到另一栏目',
    'Task modification' => '任务修改',
    'Task creation' => '任务创建',
    'Closing a task' => '正在关闭任务',
    'Assign a color to a specific user' => '为特定用户指派颜色',
    'Position' => '位置',
    'Duplicate to project' => '复制到另一项目',
    'Duplicate' => '复制',
    'Link' => '连接',
    'Comment updated successfully.' => '评论成功更新。',
    'Unable to update your comment.' => '无法更新您的评论。',
    'Remove a comment' => '移除评论',
    'Comment removed successfully.' => '评论成功移除。',
    'Unable to remove this comment.' => '无法移除该评论。',
    'Do you really want to remove this comment?' => '确定要移除评论吗？',
    'Current password for the user "%s"' => '用户"%s"的当前密码',
    'The current password is required' => '需要输入当前密码',
    'Wrong password' => '密码错误',
    'Unknown' => '未知',
    'Last logins' => '上次登录',
    'Login date' => '登录日期',
    'Authentication method' => '认证方式',
    'IP address' => 'IP地址',
    'User agent' => '浏览器标识',
    'Persistent connections' => '登录会话',
    'No session.' => '无会话',
    'Expiration date' => '过期日期',
    'Remember Me' => '记住我',
    'Creation date' => '创建日期',
    'Everybody' => '所有人',
    'Open' => '打开',
    'Closed' => '关闭',
    'Search' => '查找',
    'Nothing found.' => '没找到。',
    'Due date' => '到期时间',
    'Description' => '描述',
    '%d comments' => '%d个评论',
    '%d comment' => '%d个评论',
    'Email address invalid' => '邮件地址无效',
    'Your external account is not linked anymore to your profile.' => '你的外部账户关联已解除',
    'Unable to unlink your external account.' => '无法关联到你的外部账户',
    'External authentication failed' => '外部认证失败',
    'Your external account is linked to your profile successfully.' => '你已成功关联到你的外部账户',
    'Email' => '邮件',
    'Task removed successfully.' => '任务成功去除',
    'Unable to remove this task.' => '无法移除该任务。',
    'Remove a task' => '移除一个任务',
    'Do you really want to remove this task: "%s"?' => '确定要移除任务"%s"吗？',
    'Assign automatically a color based on a category' => '基于一个分类自动指派颜色',
    'Assign automatically a category based on a color' => '基于一种颜色自动指派分类',
    'Task creation or modification' => '任务创建或修改',
    'Category' => '分类',
    'Category:' => '分类：',
    'Categories' => '分类',
    'Your category has been created successfully.' => '成功为您创建分类。',
    'This category has been updated successfully.' => '成功为您更新分类。',
    'Unable to update this category.' => '无法为您更新分类。',
    'Remove a category' => '移除一个分类',
    'Category removed successfully.' => '分类成功移除。',
    'Unable to remove this category.' => '无法移除该分类。',
    'Category modification for the project "%s"' => '为项目"%s"修改分类',
    'Category Name' => '分类名称',
    'Add a new category' => '加入新分类',
    'Do you really want to remove this category: "%s"?' => '确定要移除分类"%s"吗？',
    'All categories' => '所有分类',
    'No category' => '无分类',
    'The name is required' => '必须要有名字',
    'Remove a file' => '移除一个文件',
    'Unable to remove this file.' => '无法移除该文件。',
    'File removed successfully.' => '文件成功移除。',
    'Attach a document' => '附加文档',
    'Do you really want to remove this file: "%s"?' => '确定要移除文件"%s"吗？',
    'Attachments' => '附件',
    'Edit the task' => '修改任务',
    'Add a comment' => '添加评论',
    'Edit a comment' => '编辑评论',
    'Summary' => '概要',
    'Time tracking' => '时间记录',
    'Estimate:' => '评估：',
    'Spent:' => '花费：',
    'Do you really want to remove this sub-task?' => '请确认是否要删除此子任务？',
    'Remaining:' => '剩余：',
    'hours' => '小时',
    'estimated' => '评估',
    'Sub-Tasks' => '子任务',
    'Add a sub-task' => '添加子任务',
    'Original estimate' => '初步预估',
    'Create another sub-task' => '创建另一个子任务',
    'Time spent' => '时间花费',
    'Edit a sub-task' => '编辑子任务',
    'Remove a sub-task' => '删除子任务',
    'The time must be a numeric value' => '时间必须为数字',
    'Todo' => '待完成',
    'In progress' => '正在进行',
    'Sub-task removed successfully.' => '成功删除子任务',
    'Unable to remove this sub-task.' => '无法删除此任务',
    'Sub-task updated successfully.' => '成功创建子任务',
    'Unable to update your sub-task.' => '无法更新子任务',
    'Unable to create your sub-task.' => '无法创建子任务',
    'Maximum size: ' => '大小上限：',
    'Display another project' => '显示其它项目',
    'Created by %s' => '创建者：%s',
    'Tasks Export' => '任务导出',
    'Start Date' => '开始时间',
    'Execute' => '执行',
    'Task Id' => '任务ID',
    'Creator' => '创建者',
    'Modification date' => '修改日期',
    'Completion date' => '完成日期',
    'Clone' => '克隆',
    'Project cloned successfully.' => '成功复制项目。',
    'Unable to clone this project.' => '无法复制此项目',
    'Enable email notifications' => '启用邮件通知',
    'Task position:' => '任务位置：',
    'The task #%d has been opened.' => '任务#%d已经被开启.',
    'The task #%d has been closed.' => '任务#%d已经被关闭.',
    'Sub-task updated' => '子任务更新',
    'Title:' => '标题：',
    'Status:' => '状态：',
    'Assignee:' => '指派给',
    'Time tracking:' => '时间记录',
    'New sub-task' => '新建子任务',
    'New attachment added "%s"' => '新附件已添加"%s"',
    'New comment posted by %s' => '%s 的新评论',
    'New comment' => '新建评论',
    'Comment updated' => '更新了评论',
    'New subtask' => '新建子任务',
    'I only want to receive notifications for these projects:' => '我仅需要收到下面项目的通知：',
    'view the task on Kanboard' => '在看板中查看此任务',
    'Public access' => '公开访问',
    'Disable public access' => '停止公开访问',
    'Enable public access' => '开启公开访问',
    'Public access disabled' => '已经禁止公开访问',
    'Move the task to another project' => '移动任务到其它项目',
    'Move to project' => '移动到其它项目',
    'Do you really want to duplicate this task?' => '确定要复制此任务吗？',
    'Duplicate a task' => '复制任务',
    'External accounts' => '外部账户',
    'Account type' => '账户类型',
    'Local' => '本地',
    'Remote' => '远程',
    'Enabled' => '启用',
    'Disabled' => '停用',
    'Login:' => '用户名：',
    'Full Name:' => '姓名：',
    'Email:' => '邮件：',
    'Notifications:' => '通知：',
    'Notifications' => '通知设定',
    'Account type:' => '账户类型：',
    'Edit profile' => '编辑属性',
    'Change password' => '修改密码',
    'Password modification' => '修改密码',
    'External authentications' => '外部认证',
    'Never connected.' => '从未连接。',
    'No external authentication enabled.' => '未启用外部认证。',
    'Password modified successfully.' => '已经成功修改密码。',
    'Unable to change the password.' => '无法修改密码。',
    'Change category' => '变更分类',
    '%s updated the task %s' => '%s 更新了任务 %s',
    '%s opened the task %s' => '%s 开启了任务 %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s 将任务 %s 移动到了"%s"的第#%d个位置',
    '%s moved the task %s to the column "%s"' => '%s 移动任务 %s 到栏目 "%s"',
    '%s created the task %s' => '%s 创建了任务 %s',
    '%s closed the task %s' => '%s 关闭了任务 %s',
    '%s created a subtask for the task %s' => '%s 创建了 %s的子任务',
    '%s updated a subtask for the task %s' => '%s 更新了 %s的子任务',
    'Assigned to %s with an estimate of %s/%sh' => '分配给 %s，预估需要 %s/%s 小时',
    'Not assigned, estimate of %sh' => '未指派，预估需要 %s 小时',
    '%s updated a comment on the task %s' => '%s 更新了任务 %s的评论',
    '%s commented the task %s' => '%s 评论了任务 %s',
    '%s\'s activity' => '%s的动态',
    'RSS feed' => 'RSS 链接',
    '%s updated a comment on the task #%d' => '%s 更新了任务 #%d 的评论',
    '%s commented on the task #%d' => '%s 评论了任务 #%d',
    '%s updated a subtask for the task #%d' => '%s 更新了任务 #%d 的子任务',
    '%s created a subtask for the task #%d' => '%s 创建了任务 #%d 的子任务',
    '%s updated the task #%d' => '%s 更新了任务 #%d',
    '%s created the task #%d' => '%s 创建了任务 #%d',
    '%s closed the task #%d' => '%s 关闭了任务 #%d',
    '%s opened the task #%d' => '%s 开启了任务 #%d',
    'Activity' => '项目动态',
    'Default values are "%s"' => '默认值为 "%s"',
    'Default columns for new projects (Comma-separated)' => '新建项目的默认栏目(用逗号分开)',
    'Task assignee change' => '任务受理人变更',
    '%s changed the assignee of the task #%d to %s' => '%s 将任务 #%d 指派给了 %s',
    '%s changed the assignee of the task %s to %s' => '%s 将任务 %s 指派给 %s',
    'New password for the user "%s"' => '用户"%s"的新密码',
    'Choose an event' => '选择一个事件',
    'Create a task from an external provider' => '从外部创建任务',
    'Change the assignee based on an external username' => '根据外部用户名修改任务受理人',
    'Change the category based on an external label' => '根据外部标签修改分类',
    'Reference' => '参考',
    'Label' => '标签',
    'Database' => '数据库',
    'About' => '关于',
    'Database driver:' => '数据库驱动：',
    'Board settings' => '看板设置',
    'Webhook settings' => 'Webhook 设置',
    'Reset token' => '重置令牌',
    'API endpoint:' => 'API 端点：',
    'Refresh interval for personal board' => '私人看板的刷新时间',
    'Refresh interval for public board' => '公共看板的刷新时间',
    'Task highlight period' => '任务高亮时间',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => '多久内的任务视作刚刚修改(单位：秒,设置为0停用，默认是2天',
    'Frequency in second (60 seconds by default)' => '频率,单位为秒(默认是60秒)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => '频率,单位为秒(设置为0停用此功能，默认是10秒)',
    'Application URL' => '应用URL',
    'Token regenerated.' => '重新生成令牌',
    'Date format' => '日期格式',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO 格式总是允许的，例如："%s" 和 "%s"',
    'New personal project' => '新建私有项目',
    'This project is personal' => '此项目为私有项目',
    'Add' => '添加',
    'Start date' => '启动日期',
    'Time estimated' => '预计时间',
    'There is nothing assigned to you.' => '当前无任务指派给你。',
    'My tasks' => '我的任务',
    'Activity stream' => '动态记录',
    'Dashboard' => '面板',
    'Confirmation' => '确认',
    'Webhooks' => '网络钩子',
    'API' => '应用程序接口',
    'Create a comment from an external provider' => '从外部创建一个评论',
    'Project management' => '项目管理',
    'Columns' => '栏目',
    'Task' => '任务',
    'Percentage' => '百分比',
    'Number of tasks' => '任务数',
    'Task distribution' => '任务分布',
    'Analytics' => '统计分析',
    'Subtask' => '子任务',
    'User repartition' => '用户分析',
    'Clone this project' => '复制此项目',
    'Column removed successfully.' => '成功删除了栏目。',
    'Not enough data to show the graph.' => '数据不足，无法绘图。',
    'Previous' => '后退',
    'The id must be an integer' => '编号必须为整数',
    'The project id must be an integer' => '项目编号必须为整数',
    'The status must be an integer' => '状态必须为整数',
    'The subtask id is required' => '必须提供子任务编号',
    'The subtask id must be an integer' => '子任务编号必须为整数',
    'The task id is required' => '需要任务编号',
    'The task id must be an integer' => '任务编号必须为整数',
    'The user id must be an integer' => '用户编号必须为整数',
    'This value is required' => '必须给出这个值',
    'This value must be numeric' => '这个值必须为数字',
    'Unable to create this task.' => '无法创建此任务。',
    'Cumulative flow diagram' => '累积流图表',
    'Daily project summary' => '每日项目汇总',
    'Daily project summary export' => '导出每日项目汇总',
    'Exports' => '导出任务',
    'This export contains the number of tasks per column grouped per day.' => '此导出包含每列的任务数，按天分组',
    'Active swimlanes' => '活动泳道',
    'Add a new swimlane' => '添加新泳道',
    'Default swimlane' => '默认泳道',
    'Do you really want to remove this swimlane: "%s"?' => '确定要删除泳道："%s"?',
    'Inactive swimlanes' => '非活动泳道',
    'Remove a swimlane' => '删除泳道',
    'Swimlane modification for the project "%s"' => '项目"%s"的泳道变更',
    'Swimlane removed successfully.' => '成功删除泳道',
    'Swimlanes' => '泳道',
    'Swimlane updated successfully.' => '成功更新了泳道。',
    'Unable to remove this swimlane.' => '无法删除此泳道',
    'Unable to update this swimlane.' => '无法更新此泳道',
    'Your swimlane has been created successfully.' => '已经成功创建泳道。',
    'Example: "Bug, Feature Request, Improvement"' => '示例：“缺陷，功能需求，提升',
    'Default categories for new projects (Comma-separated)' => '新项目的默认分类(用逗号分隔)',
    'Integrations' => '整合',
    'Integration with third-party services' => '与第三方服务进行整合',
    'Subtask Id' => '子任务 Id',
    'Subtasks' => '子任务',
    'Subtasks Export' => '子任务导出',
    'Task Title' => '任务标题',
    'Untitled' => '无标题',
    'Application default' => '程序默认',
    'Language:' => '语言：',
    'Timezone:' => '时区：',
    'All columns' => '全部栏目',
    'Next' => '前进',
    '#%d' => '#%d',
    'All swimlanes' => '全部泳道',
    'All colors' => '全部颜色',
    'Moved to column %s' => '移动到栏目 %s',
    'User dashboard' => '用户仪表板',
    'Allow only one subtask in progress at the same time for a user' => '每用户同时仅有一个活动子任务',
    'Edit column "%s"' => '编辑栏目"%s"',
    'Select the new status of the subtask: "%s"' => '选择子任务的新状态："%s"',
    'Subtask timesheet' => '子任务时间',
    'There is nothing to show.' => '当前无内容可展示。',
    'Time Tracking' => '时间记录',
    'You already have one subtask in progress' => '你已经有了一个进行中的子任务',
    'Which parts of the project do you want to duplicate?' => '要复制项目的哪些内容？',
    'Disallow login form' => '禁止登陆',
    'Start' => '开始',
    'End' => '结束',
    'Task age in days' => '任务存在天数',
    'Days in this column' => '在此栏目的天数',
    '%dd' => '%d天',
    'Add a new link' => '添加一个新关联',
    'Do you really want to remove this link: "%s"?' => '确认要删除此关联吗:"%s"?',
    'Do you really want to remove this link with task #%d?' => '确认要删除到任务 #%d 的关联吗？',
    'Field required' => '必须的字段',
    'Link added successfully.' => '成功添加关联。',
    'Link updated successfully.' => '成功更新关联。',
    'Link removed successfully.' => '成功删除关联。',
    'Link labels' => '关联标签',
    'Link modification' => '关联修改',
    'Opposite label' => '反向标签',
    'Remove a link' => '删除关联',
    'The labels must be different' => '标签不能一样',
    'There is no link.' => '当前没有关联',
    'This label must be unique' => '关联必须唯一',
    'Unable to create your link.' => '无法创建关联。',
    'Unable to update your link.' => '无法更新关联。',
    'Unable to remove this link.' => '无法删除关联。',
    'relates to' => '关联到',
    'blocks' => '阻塞',
    'is blocked by' => '阻塞于',
    'duplicates' => '重复',
    'is duplicated by' => '重复于',
    'is a child of' => '子任务自',
    'is a parent of' => '父任务于',
    'targets milestone' => '里程碑目标',
    'is a milestone of' => '属于里程碑',
    'fixes' => '修复',
    'is fixed by' => '修复于',
    'This task' => '此任务',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => '展开任务',
    'Collapse tasks' => '折叠任务',
    'Expand/collapse tasks' => '展开/折叠任务',
    'Close dialog box' => '关闭对话框',
    'Submit a form' => '提交表单',
    'Board view' => '面板视图',
    'Keyboard shortcuts' => '键盘快捷方式',
    'Open board switcher' => '打开面板切换器',
    'Application' => '应用程序',
    'Compact view' => '紧凑视图',
    'Horizontal scrolling' => '水平滚动',
    'Compact/wide view' => '紧凑/宽视图',
    'Currency' => '货币',
    'Personal project' => '私有项目',
    'AUD - Australian Dollar' => '澳元',
    'CAD - Canadian Dollar' => '加元',
    'CHF - Swiss Francs' => '瑞士法郎',
    'Custom Stylesheet' => '自定义样式表',
    'EUR - Euro' => '欧元',
    'GBP - British Pound' => '英镑',
    'INR - Indian Rupee' => '印度卢比',
    'JPY - Japanese Yen' => '日元',
    'NZD - New Zealand Dollar' => '新西兰元',
    // 'PEN - Peruvian Sol' => '',
    'RSD - Serbian dinar' => '第纳尔',
    'CNY - Chinese Yuan' => '人民币',
    'USD - US Dollar' => '美元',
    'VES - Venezuelan Bolívar' => '委内瑞拉玻利瓦尔',
    'Destination column' => '目标栏目',
    'Move the task to another column when assigned to a user' => '指定受理人时移动到其它栏目',
    'Move the task to another column when assignee is cleared' => '移除受理人时移动到其它栏目',
    'Source column' => '原栏目',
    'Transitions' => '变更',
    'Executer' => '执行者',
    'Time spent in the column' => '栏目中的时间消耗',
    'Task transitions' => '任务变更',
    'Task transitions export' => '导出任务变更',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => '此报告记录任务的变更，包含日期、用户和时间消耗。',
    'Currency rates' => '汇率',
    'Rate' => '汇率',
    'Change reference currency' => '修改参考货币',
    'Reference currency' => '参考货币',
    'The currency rate has been added successfully.' => '成功添加汇率。',
    'Unable to add this currency rate.' => '无法添加此汇率',
    'Webhook URL' => '网络钩子 URL',
    '%s removed the assignee of the task %s' => '%s删除了任务%s的受理人',
    'Information' => '信息',
    'Check two factor authentication code' => '检查双重认证码',
    'The two factor authentication code is not valid.' => '双重认证码不正确。',
    'The two factor authentication code is valid.' => '双重认证码正确。',
    'Code' => '认证码',
    'Two factor authentication' => '双重认证',
    'This QR code contains the key URI: ' => '此二维码包含密码 URI:',
    'Check my code' => '检查我的认证码',
    'Secret key: ' => '密码：',
    'Test your device' => '测试设备',
    'Assign a color when the task is moved to a specific column' => '任务移动到指定栏目时设置颜色',
    '%s via Kanboard' => '%s 通过KanBoard',
    'Burndown chart' => '燃尽图',
    'This chart show the task complexity over the time (Work Remaining).' => '图表显示任务随时间(剩余时间)的复杂度',
    'Screenshot taken %s' => '已截图 %s',
    'Add a screenshot' => '添加截图',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => '获取截图并按CTRL+V或者⌘+V粘贴到这里',
    'Screenshot uploaded successfully.' => '截图上传成功',
    'SEK - Swedish Krona' => '瑞郎',
    'Identifier' => '标识符',
    'Disable two factor authentication' => '禁用双重认证',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => '你真的要禁用 "%s" 的双重认证吗？',
    'Edit link' => '编辑链接',
    'Start to type task title...' => '输入任务标题...',
    'A task cannot be linked to itself' => '任务不能关联到本身',
    'The exact same link already exists' => '相同的关联已存在',
    'Recurrent task is scheduled to be generated' => '循环性任务将按计划生成',
    'Score' => '积分',
    'The identifier must be unique' => '标识符必须唯一',
    'This linked task id doesn\'t exists' => '关联任务不存在',
    'This value must be alphanumeric' => '此值必须是字母或者数字',
    'Edit recurrence' => '编辑循环周期',
    'Generate recurrent task' => '生成循环任务',
    'Trigger to generate recurrent task' => '生成循环任务的触发器',
    'Factor to calculate new due date' => '新到期时间的计算因子',
    'Timeframe to calculate new due date' => '新到期时间的计算周期',
    'Base date to calculate new due date' => '新到期时间的计算基准',
    'Action date' => '操作日期',
    'Base date to calculate new due date: ' => '基准日期',
    'This task has created this child task: ' => '此任务创建了子任务：',
    'Day(s)' => '天',
    'Existing due date' => '当前到期时间',
    'Factor to calculate new due date: ' => '新到期时间的计算因子：',
    'Month(s)' => '月',
    'This task has been created by: ' => '此任务被谁创建：',
    'Recurrent task has been generated:' => '循环任务已生成：',
    'Timeframe to calculate new due date: ' => '新到期时间的计算周期：',
    'Trigger to generate recurrent task: ' => '生成循环任务的触发器',
    'When task is closed' => '当任务关闭时',
    'When task is moved from first column' => '当任务从第一列任务栏移走时',
    'When task is moved to last column' => '当任务移动到最后一列任务栏时',
    'Year(s)' => '年',
    'Project settings' => '项目设置',
    'Automatically update the start date' => '自动更新开始日期',
    'iCal feed' => '日历订阅',
    'Preferences' => '偏好',
    'Security' => '安全',
    'Two factor authentication disabled' => '双重认证已禁用',
    'Two factor authentication enabled' => '双重认证已启用',
    'Unable to update this user.' => '无法更新此用户',
    'There is no user management for personal projects.' => '私有项目下无用户可管理',
    'User that will receive the email' => '用户将收到邮件',
    'Email subject' => '邮件主题',
    'Date' => '日期',
    'Add a comment log when moving the task between columns' => '当任务在栏目间移动时添加评论日志',
    'Move the task to another column when the category is changed' => '当任务分类改变时移动到另一栏',
    'Send a task by email to someone' => '发送任务邮件到用户',
    'Reopen a task' => '重新开始一个任务',
    'Notification' => '通知',
    '%s moved the task #%d to the first swimlane' => '%s将任务#%d移动到了首个泳道',
    'Swimlane' => '泳道',
    '%s moved the task %s to the first swimlane' => '%s将任务%s移动到了首个泳道',
    '%s moved the task %s to the swimlane "%s"' => '%s将任务%s移动到了泳道"%s"下',
    'This report contains all subtasks information for the given date range.' => '该报告包含了指定日期范围内的所有子任务信息。',
    'This report contains all tasks information for the given date range.' => '该报告包含了指定日期范围内的所有任务信息。',
    'Project activities for %s' => '%s的项目活动记录',
    'view the board on Kanboard' => '在看板上查看面板',
    'The task has been moved to the first swimlane' => '该任务已被移动到首个泳道',
    'The task has been moved to another swimlane:' => '该任务已被移动到别的泳道：',
    'New title: %s' => '新标题：%s',
    'The task is not assigned anymore' => '该任务没有指派给任何人',
    'New assignee: %s' => '新指派到：%s',
    'There is no category now' => '当前没有分类',
    'New category: %s' => '新分类：%s',
    'New color: %s' => '新颜色：%s',
    'New complexity: %d' => '新的复杂度：%d',
    'The due date has been removed' => '超期时间已被移除',
    'There is no description anymore' => '当前没有描述',
    'Recurrence settings has been modified' => '循环周期已被更改',
    'Time spent changed: %sh' => '时间花费已变更：%sh',
    'Time estimated changed: %sh' => '时间预估已变更：%sh',
    'The field "%s" has been updated' => '"%s"字段已更新',
    'The description has been modified:' => '描述已更改',
    'Do you really want to close the task "%s" as well as all subtasks?' => '你是否要移除所有子任务的同时父任务"%s"',
    'I want to receive notifications for:' => '我想接收以下相关通知：',
    'All tasks' => '所有任务',
    'Only for tasks assigned to me' => '所有指派给我的任务',
    'Only for tasks created by me' => '所有我创建的任务',
    'Only for tasks created by me and tasks assigned to me' => '所有我创建的和指派给我的任务',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => '所有栏目下的',
    'You need at least 2 days of data to show the chart.' => '当前柱状图至少需要2天的数据。',
    '<15m' => '小于15分钟',
    '<30m' => '小于30分钟',
    'Stop timer' => '停止计时器',
    'Start timer' => '开启计时器',
    'My activity stream' => '我的动态',
    'Search tasks' => '搜索任务',
    'Reset filters' => '重置过滤器',
    'My tasks due tomorrow' => '我的明天到期的任务',
    'Tasks due today' => '今天到期的任务',
    'Tasks due tomorrow' => '明天到期的任务',
    'Tasks due yesterday' => '昨天到期的任务',
    'Closed tasks' => '已关闭任务',
    'Open tasks' => '打开的任务',
    'Not assigned' => '未指派',
    'View advanced search syntax' => '查看高级搜索语法',
    'Overview' => '概览',
    'Board/Calendar/List view' => '看板/日程/列表视图',
    'Switch to the board view' => '切换到看板视图',
    'Switch to the list view' => '切换到列表视图',
    'Go to the search/filter box' => '前往搜索/过滤箱',
    'There is no activity yet.' => '当前无任何活动。',
    'No tasks found.' => '没有找到任何任务。',
    'Keyboard shortcut: "%s"' => '快捷键: "%s"',
    'List' => '列表',
    'Filter' => '过滤器',
    'Advanced search' => '高级搜索',
    'Example of query: ' => '查询示例：',
    'Search by project: ' => '按项目：',
    'Search by column: ' => '按任务栏：',
    'Search by assignee: ' => '按受理人：',
    'Search by color: ' => '按颜色: ',
    'Search by category: ' => '按分类：',
    'Search by description: ' => '按描述：',
    'Search by due date: ' => '按超期时间：',
    'Average time spent in each column' => '每个任务栏的平均花费时间',
    'Average time spent' => '平均花费时间',
    'This chart shows the average time spent in each column for the last %d tasks.' => '当前柱状图表示最新%d条任务在每个任务栏下的平均花费时间',
    'Average Lead and Cycle time' => '平均工作时间和平均周期时间',
    'Average lead time: ' => '平均工作时间',
    'Average cycle time: ' => '平均周期时间：',
    'Cycle Time' => '周期时间',
    'Lead Time' => '工作时间',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => '该图表显示了过去 %d 个任务的平均和峰值耗时。',
    'Average time into each column' => '每个任务栏的平均时间',
    'Lead and cycle time' => '工作时间和周期时间',
    'Lead time: ' => '工作时间: ',
    'Cycle time: ' => '周期时间: ',
    'Time spent in each column' => '每个任务栏的花费时间',
    'The lead time is the duration between the task creation and the completion.' => '工作时间是任务创建和完成之间的持续时间。',
    'The cycle time is the duration between the start date and the completion.' => '周期时间是开始日期和完成时间之间的持续时间。',
    'If the task is not closed the current time is used instead of the completion date.' => '如果当前任务未关闭时用当前时间代替完成时间',
    'Set the start date automatically' => '设置自动开始日期',
    'Edit Authentication' => '编辑认证信息',
    'Remote user' => '远程用户',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => '远程用户不会在看板数据库保存密码，例如：LDAP,GOOGLE,GitHub。',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => '如果选中“禁止登陆来自”，登陆表单内的验证信息将被忽略。',
    'Default task color' => '默认任务颜色',
    'This feature does not work with all browsers.' => '本功能只在部分浏览器下工作正常。',
    'There is no destination project available.' => '当前没有目标项目可用',
    'Trigger automatically subtask time tracking' => '自动跟踪子任务时间',
    'Include closed tasks in the cumulative flow diagram' => '在累计流程图中包含已关闭任务',
    'Current swimlane: %s' => '当前泳道：%s',
    'Current column: %s' => '当前任务栏：%s',
    'Current category: %s' => '当前分类：%s',
    'no category' => '无分类',
    'Current assignee: %s' => '当前受理人: %s',
    'not assigned' => '未指派',
    'Author:' => '作者',
    'contributors' => '贡献者',
    'License:' => '授权许可:',
    'License' => '授权许可',
    'Enter the text below' => '输入下方的文本',
    'Start date:' => '开始日期',
    'Due date:' => '到期日期',
    'People who are project managers' => '项目管理员',
    'People who are project members' => '项目成员',
    'NOK - Norwegian Krone' => '克朗',
    'Show this column' => '显示任务栏',
    'Hide this column' => '隐藏任务栏',
    'End date' => '结束日期',
    'Users overview' => '用户概览',
    'Members' => '成员',
    'Shared project' => '公开项目',
    'Project managers' => '项目管理员',
    'Projects list' => '项目列表',
    'End date:' => '结束日期',
    'Change task color when using a specific task link' => '当任务关联到指定任务时改变颜色',
    'Task link creation or modification' => '任务链接创建或更新时间',
    'Milestone' => '里程碑',
    'Reset the search/filter box' => '重置搜索/过滤框',
    'Documentation' => '帮助文档',
    'Author' => '作者',
    'Version' => '版本',
    'Plugins' => '插件管理',
    'There is no plugin loaded.' => '当前没有插件载入',
    'My notifications' => '我的通知',
    'Custom filters' => '过滤器',
    'Your custom filter has been created successfully.' => '成功创建过滤器',
    'Unable to create your custom filter.' => '无法创建过滤器',
    'Custom filter removed successfully.' => '成功删除过滤器',
    'Unable to remove this custom filter.' => '无法删除这个过滤器',
    'Edit custom filter' => '编辑过滤器',
    'Your custom filter has been updated successfully.' => '你的过滤器更新成功',
    'Unable to update custom filter.' => '无法更新过滤器',
    'Web' => 'web',
    'New attachment on task #%d: %s' => '任务#%d下的新附件：%s',
    'New comment on task #%d' => '任务#%d下的新评论',
    'Comment updated on task #%d' => '任务#%d的评论已更新',
    'New subtask on task #%d' => '任务#%d下新的子任务',
    'Subtask updated on task #%d' => '任务#%d下的子任务已更新',
    'New task #%d: %s' => '新任务#%d：%s',
    'Task updated #%d' => '任务#%d已更新',
    'Task #%d closed' => '任务#%d已关闭',
    'Task #%d opened' => '任务#%d已打开',
    'Column changed for task #%d' => '任务#%d的任务栏已改变',
    'New position for task #%d' => '任务#%d的新状态',
    'Swimlane changed for task #%d' => '任务#%d的泳道已改变',
    'Assignee changed on task #%d' => '任务#%d的指派人已改变',
    '%d overdue tasks' => '%d条超期任务',
    'Task #%d is overdue' => '任务#%d已超期',
    'No notification.' => '没有新通知',
    'Mark all as read' => '标记所有为已读',
    'Mark as read' => '标记为已读',
    'Total number of tasks in this column across all swimlanes' => '此任务栏下的任务数（跨泳道）',
    'Collapse swimlane' => '收起泳道',
    'Expand swimlane' => '展开泳道',
    'Add a new filter' => '添加新过滤器',
    'Share with all project members' => '对项目所有成员共享',
    'Shared' => '共享',
    'Owner' => '所有人',
    'Unread notifications' => '未读通知',
    'Notification methods:' => '通知提醒方式：',
    'Unable to read your file' => '无法读取文件',
    '%d task(s) have been imported successfully.' => '成功导入%d条任务。',
    'Nothing has been imported!' => '没有信息被导入！',
    'Import users from CSV file' => '从CSV文件导入用户',
    '%d user(s) have been imported successfully.' => '成功导入%d个用户。',
    'Comma' => '逗号',
    'Semi-colon' => '分号',
    'Tab' => '制表符',
    'Vertical bar' => '竖线',
    'Double Quote' => '双引号',
    'Single Quote' => '单引号',
    '%s attached a file to the task #%d' => '%s添加文件到任务#%d',
    'There is no column or swimlane activated in your project!' => '当前项目没有活动任务栏或泳道',
    'Append filter (instead of replacement)' => '追加过滤',
    'Append/Replace' => '追加/替换',
    'Append' => '追加',
    'Replace' => '替换',
    'Import' => '导入',
    'Change sorting' => '改变排序',
    'Tasks Importation' => '任务重要性',
    'Delimiter' => '分隔符',
    'Enclosure' => '附件',
    'CSV File' => 'CSV文件',
    'Instructions' => '操作指南',
    'Your file must use the predefined CSV format' => '文件必须为预定格式的CSV文件',
    'Your file must be encoded in UTF-8' => '文件编码必须为UTF-8',
    'The first row must be the header' => '第一行必须为表头',
    'Duplicates are not verified for you' => '无法验证重复信息',
    'The due date must use the ISO format: YYYY-MM-DD' => '超期日期必须为ISO格式：YYYY-MM-DD',
    'Download CSV template' => '下载CSV模板',
    'No external integration registered.' => '没有外部注册信息',
    'Duplicates are not imported' => '重复信息未导入',
    'Usernames must be lowercase and unique' => '用户名必须小写且唯一',
    'Passwords will be encrypted if present' => '密码将被加密',
    '%s attached a new file to the task %s' => '"%s"添加了附件到任务"%s"',
    'Link type' => '关联类型',
    'Assign automatically a category based on a link' => '基于链接自动关联分类',
    'BAM - Konvertible Mark' => '波斯尼亚马克',
    'Assignee Username' => '指派用户名',
    'Assignee Name' => '指派名称',
    'Groups' => '用户组',
    'Members of %s' => '“%s”组成员',
    'New group' => '新加用户组',
    'Group created successfully.' => '用户组创建成功',
    'Unable to create your group.' => '无法创建你的用户组',
    'Edit group' => '编辑用户组',
    'Group updated successfully.' => '用户组更新成功',
    'Unable to update your group.' => '无法更新你的用户组',
    'Add group member to "%s"' => '添加到用户组"%s"',
    'Group member added successfully.' => '成功添加用户组成员',
    'Unable to add group member.' => '无法添加用户组成员',
    'Remove user from group "%s"' => '从"%s"组中移除用户',
    'User removed successfully from this group.' => '用户已从该用户组中删除',
    'Unable to remove this user from the group.' => '无法从该用户组中删除用户',
    'Remove group' => '删除用户组',
    'Group removed successfully.' => '用户组已删除',
    'Unable to remove this group.' => '无法删除该用户组',
    'Project Permissions' => '项目权限',
    'Manager' => '管理员',
    'Project Manager' => '项目管理员',
    'Project Member' => '项目成员',
    'Project Viewer' => '项目观察员',
    'Your account is locked for %d minutes' => '你的账户被锁定%d分钟',
    'Invalid captcha' => '验证码无效',
    'The name must be unique' => '请确保用户名唯一',
    'View all groups' => '查看所有用户组',
    'There is no user available.' => '当前没有有效用户',
    'Do you really want to remove the user "%s" from the group "%s"?' => '你确定把用户"%s"从"%s"中移除？',
    'There is no group.' => '当前没有用户组',
    'Add group member' => '添加用户组成员',
    'Do you really want to remove this group: "%s"?' => '你真的想要移除用户组："%s"？',
    'There is no user in this group.' => '当前用户组下没有成员',
    'Permissions' => '权限',
    'Allowed Users' => '被允许的用户',
    'No specific user has been allowed.' => '没有被允许的用户。',
    'Role' => '角色',
    'Enter user name...' => '输入用户名...',
    'Allowed Groups' => '被允许的用户组',
    'No group has been allowed.' => '没有被允许的用户组。',
    'Group' => '用户组',
    'Group Name' => '用户组名称',
    'Enter group name...' => '输入用户组名称...',
    'Role:' => '角色:',
    'Project members' => '项目成员',
    '%s mentioned you in the task #%d' => '%s在任务#%d里提及你',
    '%s mentioned you in a comment on the task #%d' => '%s在任务#%d的评论里提及你',
    'You were mentioned in the task #%d' => '你在任务#%d里被提及',
    'You were mentioned in a comment on the task #%d' => '你在任务#%d的评论里被提及',
    'Estimated hours: ' => '预估小时数',
    'Actual hours: ' => '实际小时数',
    'Hours Spent' => '花费小时数',
    'Hours Estimated' => '预估小时数',
    'Estimated Time' => '预估时间',
    'Actual Time' => '实际时间',
    'Estimated vs actual time' => '预估时间 VS 实际时间',
    'RUB - Russian Ruble' => '卢布',
    'Assign the task to the person who does the action when the column is changed' => '当任务所属任务栏改变时分配到指定用户',
    'Close a task in a specific column' => '关闭指定任务栏下的任务',
    'Time-based One-time Password Algorithm' => '基于时间的一次性密码算法',
    'Two-Factor Provider: ' => '双重认证提供商',
    'Disable two-factor authentication' => '禁用双重认证',
    'Enable two-factor authentication' => '启用双重认证',
    'There is no integration registered at the moment.' => '当前没有注册关联',
    'Password Reset for Kanboard' => '重置kanboard密码',
    'Forgot password?' => '忘记密码？',
    'Enable "Forget Password"' => '启用找回密码',
    'Password Reset' => '密码重置',
    'New password' => '新密码',
    'Change Password' => '更改密码',
    'To reset your password click on this link:' => '点击此链接重置你的密码',
    'Last Password Reset' => '上次密码重置',
    'The password has never been reinitialized.' => '密码从未被重新初始化',
    'Creation' => '创建时间',
    'Expiration' => '过期时间',
    'Password reset history' => '密码历史',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '任务栏 "%s" 和 泳道 "%s" 下的所有任务已关闭',
    'Do you really want to close all tasks of this column?' => '你确定要关闭此任务栏下的所有任务？',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '任务栏 "%s" 和 泳道 "%s" 下 %d 条任务将被关闭。',
    'Close all tasks in this column and this swimlane' => '关闭此任务栏下的所有任务',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => '没有插件注册到项目通知接口，你仍然可以在你个人设置里启用单独的通知',
    'My dashboard' => '我的看板',
    'My profile' => '个人信息',
    'Project owner: ' => '项目负责人',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => '项目标识符是可选的,且只能是数字或字母组成，例如：MYPROJECT。',
    'Project owner' => '项目负责人',
    'Personal projects do not have users and groups management.' => '私有项目下没有成员或组可管理',
    'There is no project member.' => '当前没有项目成员',
    'Priority' => '优先级',
    'Task priority' => '任务优先级',
    'General' => '常用',
    'Dates' => '时间',
    'Default priority' => '默认优先级',
    'Lowest priority' => '最低优先级',
    'Highest priority' => '最高优先级',
    'Close a task when there is no activity' => '当任务没有活动记录时关闭任务',
    'Duration in days' => '持续天数',
    'Send email when there is no activity on a task' => '当任务没有活动记录时发送邮件',
    'Unable to fetch link information.' => '无法获取关联信息',
    'Daily background job for tasks' => '每日后台任务',
    'Auto' => '自动',
    'Related' => '相关的',
    'Attachment' => '附件',
    'Title not found' => '标题未找到',
    'Web Link' => '网页链接',
    'External links' => '外部关联',
    'Add external link' => '添加外部关联',
    'Type' => '类型',
    'Dependency' => '依赖',
    'Add internal link' => '添加内部关联',
    'Add a new external link' => '添加新的外部关联',
    'Edit external link' => '编辑外部关联',
    'External link' => '外部关联',
    'Copy and paste your link here...' => '复制并粘贴链接到当前位置...',
    'URL' => 'URL',
    'Internal links' => '内部关联',
    'Assign to me' => '指派给我',
    'Me' => '我',
    'Do not duplicate anything' => '全新项目',
    'Projects management' => '项目管理',
    'Users management' => '用户管理',
    'Groups management' => '用户组管理',
    'Create from another project' => '基于现有项目创建',
    'open' => '打开',
    'closed' => '已关闭',
    'Priority:' => '优先级：',
    'Reference:' => '引用：',
    'Complexity:' => '复杂度：',
    'Swimlane:' => '泳道：',
    'Column:' => '栏目：',
    'Position:' => '位置：',
    'Creator:' => '创建者：',
    'Time estimated:' => '预计时间：',
    '%s hours' => '%s 小时',
    'Time spent:' => '时间消耗：',
    'Created:' => '已创建：',
    'Modified:' => '已修改：',
    'Completed:' => '已完成：',
    'Started:' => '已开始：',
    'Moved:' => '已移走：',
    'Task #%d' => '任务#%d',
    'Time format' => '时间格式',
    'Start date: ' => '开始时间：',
    'End date: ' => '结束时间：',
    'New due date: ' => '新超期时间：',
    'Start date changed: ' => '开始时间已改变：',
    'Disable personal projects' => '禁用私有项目',
    'Do you really want to remove this custom filter: "%s"?' => '你确定要移除这个自定义过滤器："%s"？',
    'Remove a custom filter' => '移除过滤器',
    'User activated successfully.' => '用户已激活。',
    'Unable to enable this user.' => '无法启用该用户。',
    'User disabled successfully.' => '用户已禁用。',
    'Unable to disable this user.' => '无法禁用该用户。',
    'All files have been uploaded successfully.' => '所有文件已成功上传。',
    'The maximum allowed file size is %sB.' => '最大上传尺寸 %sB',
    'Drag and drop your files here' => '拖放文件到这里',
    'choose files' => '选择文件',
    'View profile' => '查看个人信息',
    'Two Factor' => '双重认证',
    'Disable user' => '禁用用户',
    'Do you really want to disable this user: "%s"?' => '你确定要禁用该用户："%s"？',
    'Enable user' => '启用用户',
    'Do you really want to enable this user: "%s"?' => '你确定要启用该用户："%s"？',
    'Download' => '下载',
    'Uploaded: %s' => '上传：%s',
    'Size: %s' => '大小：%s',
    'Uploaded by %s' => '由%s上传',
    'Filename' => '文件名',
    'Size' => '大小',
    'Column created successfully.' => '新增任务栏成功。',
    'Another column with the same name exists in the project' => '当前项目中重名任务栏已存在',
    'Default filters' => '默认过滤器',
    'Your board doesn\'t have any columns!' => '你的看板没有任何栏目',
    'Change column position' => '更改任务栏位置',
    'Switch to the project overview' => '切换到项目视图',
    'User filters' => '用户过滤器',
    'Category filters' => '分类过滤器',
    'Upload a file' => '上传文件',
    'View file' => '查看文件',
    'Last activity' => '最后活动',
    'Change subtask position' => '更改子任务位置',
    'This value must be greater than %d' => '当前输入值必须大于%d',
    'Another swimlane with the same name exists in the project' => '当前项目中重名泳道已存在',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => '例如： https://example.kanboard.org/（通常用于生成绝对地址）',
    'Actions duplicated successfully.' => '动作复制成功。',
    'Unable to duplicate actions.' => '无法复制动作。',
    'Add a new action' => '添加新动作',
    'Import from another project' => '从另一个项目中导入',
    'There is no action at the moment.' => '当前没有动作。',
    'Import actions from another project' => '从另一个项目中导入动作',
    'There is no available project.' => '当前没有可用项目',
    'Local File' => '本地文件',
    'Configuration' => '配置选项',
    'PHP version:' => 'PHP 版本：',
    'PHP SAPI:' => 'PHP SAPI：',
    'OS version:' => '系统：',
    'Database version:' => '数据库版本：',
    'Browser:' => '浏览器：',
    'Task view' => '任务浏览',
    'Edit task' => '编辑任务',
    'Edit description' => '编辑描述',
    'New internal link' => '新建内部链接',
    'Display list of keyboard shortcuts' => '显示快捷键列表',
    'Avatar' => '我的头像',
    'Upload my avatar image' => '上传我的头像',
    'Remove my image' => '删除我的头像',
    'The OAuth2 state parameter is invalid' => 'OAuth2状态参数无效',
    'User not found.' => '用户未找到',
    'Search in activity stream' => '在活动足迹里搜索',
    'My activities' => '我的活动足迹',
    'Activity until yesterday' => '今天以前的活动足迹',
    'Activity until today' => '今天为止的活动足迹',
    'Search by creator: ' => '以创建者搜索',
    'Search by creation date: ' => '以创建日期搜索',
    'Search by task status: ' => '以任务状态搜索',
    'Search by task title: ' => '以任务标题搜索',
    'Activity stream search' => '活动足迹搜索',
    'Projects where "%s" is manager' => '"%s"　管理的项目',
    'Projects where "%s" is member' => '"%s"　参与的项目',
    'Open tasks assigned to "%s"' => '指派给"%s"的开放任务',
    'Closed tasks assigned to "%s"' => '指派给"%s"的已结束任务',
    'Assign automatically a color based on a priority' => '基于优先级自动标记颜色',
    'Overdue tasks for the project(s) "%s"' => '"%s"项目下的超期任务',
    'Upload files' => '上传文件',
    'Installed Plugins' => '已安装插件',
    'Plugin Directory' => '插件目录',
    'Plugin installed successfully.' => '插件安装成功。',
    'Plugin updated successfully.' => '插件更新成功。',
    'Plugin removed successfully.' => '插件卸载成功。',
    'Subtask converted to task successfully.' => '子任务成功转换成普通任务。',
    'Unable to convert the subtask.' => '无法转换子任务。',
    'Unable to extract plugin archive.' => '无法解压插件包。',
    'Plugin not found.' => '插件未找到。',
    'You don\'t have the permission to remove this plugin.' => '你没有权限移除此插件。',
    'Unable to download plugin archive.' => '无法下载插件包。',
    'Unable to write temporary file for plugin.' => '无法为插件写入临时文件。',
    'Unable to open plugin archive.' => '无法打开插件包。',
    'There is no file in the plugin archive.' => '当前插件包内无文件。',
    'Create tasks in bulk' => '批量创建任务',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => '你的Kanboard没有启用插件安装。',
    'There is no plugin available.' => '当前无可用插件。',
    'Install' => '安装',
    'Update' => '更新',
    'Up to date' => '已更新',
    'Not available' => '不可用',
    'Remove plugin' => '移除插件',
    'Do you really want to remove this plugin: "%s"?' => '你真的要移除插件："%s"？',
    'Uninstall' => '移除',
    'Listing' => '列表',
    'Metadata' => '元数据',
    'Manage projects' => '管理项目',
    'Convert to task' => '转化为普通任务',
    'Convert sub-task to task' => '转化子任务为普通任务',
    'Do you really want to convert this sub-task to a task?' => '你真的要将此子任务转化为普通任务？',
    'My task title' => '我的任务标题',
    'Enter one task by line.' => '写入一行任务。',
    'Number of failed login:' => '登录失败次数：',
    'Account locked until:' => '账户被锁定至：',
    'Email settings' => '邮件设置',
    'Email sender address' => '邮件发送地址',
    'Email transport' => '邮件转发',
    'Webhook token' => 'Web钩子Token',
    'Project tags management' => '项目标签管理',
    'Tag created successfully.' => '成功创建标签。',
    'Unable to create this tag.' => '无法创建此标签。',
    'Tag updated successfully.' => '标签更新成功。',
    'Unable to update this tag.' => '无法更新此标签。',
    'Tag removed successfully.' => '标签删除成功。',
    'Unable to remove this tag.' => '无法删除此标签',
    'Global tags management' => '全局标签管理',
    'Tags' => '标签',
    'Tags management' => '标签管理',
    'Add new tag' => '添加新标签',
    'Edit a tag' => '编辑标签',
    'Project tags' => '项目标签',
    'There is no specific tag for this project at the moment.' => '当前项目没有指定任何标签。',
    'Tag' => '标签',
    'Remove a tag' => '移除标签',
    'Do you really want to remove this tag: "%s"?' => '你真的要删除此标签："%s"？',
    'Global tags' => '全局标签',
    'There is no global tag at the moment.' => '当前没有全局标签。',
    'This field cannot be empty' => '此栏不能为空',
    'Close a task when there is no activity in a specific column' => '当指定栏目没有更新时关闭任务',
    '%s removed a subtask for the task #%d' => '"%s"从任务#%d删除了子任务',
    '%s removed a comment on the task #%d' => '"%s"从任务#%d删除了评论',
    'Comment removed on task #%d' => '任务#%d上的评论已删除',
    'Subtask removed on task #%d' => '任务#%d上的子任务已删除',
    'Hide tasks in this column in the dashboard' => '在面板首页隐藏此栏下的任务',
    '%s removed a comment on the task %s' => '"%s"从任务%s 删除了评论',
    '%s removed a subtask for the task %s' => '"%s"从任务%s 删除了子任务',
    'Comment removed' => '评论已删除',
    'Subtask removed' => '子任务已删除',
    '%s set a new internal link for the task #%d' => '%s为任务#%d 设置了新内部链接',
    '%s removed an internal link for the task #%d' => '%s 从任务 #%d 删除内部链接',
    'A new internal link for the task #%d has been defined' => '#%d新内部链接已定义',
    'Internal link removed for the task #%d' => '#%d内部链接已删除',
    '%s set a new internal link for the task %s' => '%s为任务%s设置了新链接',
    '%s removed an internal link for the task %s' => '%s删除了任务%s内部链接',
    'Automatically set the due date on task creation' => '创建任务时自动设置到期时间',
    'Move the task to another column when closed' => '当任务关闭时移动到另一栏',
    'Move the task to another column when not moved during a given period' => '当任务在指定时间内未移动时，移动到另一栏',
    'Dashboard for %s' => '%s的看板',
    'Tasks overview for %s' => '%s的任务预览',
    'Subtasks overview for %s' => '%s的子任务预览',
    'Projects overview for %s' => '%s的项目预览',
    'Activity stream for %s' => '%s的活动足迹',
    'Assign a color when the task is moved to a specific swimlane' => '当任务移动到指定泳道时标记颜色',
    'Assign a priority when the task is moved to a specific swimlane' => '当任务移动到指定泳道时标记优先级',
    'User unlocked successfully.' => '用户解锁成功。',
    'Unable to unlock the user.' => '无法解锁用户。',
    'Move a task to another swimlane' => '移动任务到泳道',
    'Creator Name' => '创建人名称',
    'Time spent and estimated' => '时间花费预估',
    'Move position' => '移动位置',
    'Move task to another position on the board' => '移动任务到另一个位置',
    'Insert before this task' => '在此任务之前插入',
    'Insert after this task' => '在此任务之后插入',
    'Unlock this user' => '解锁用户',
    'Custom Project Roles' => '自定义项目角色',
    'Add a new custom role' => '添加新角色',
    'Restrictions for the role "%s"' => '"%s"角色限制',
    'Add a new project restriction' => '添加新的项目限制',
    'Add a new drag and drop restriction' => '添加新的拖放限制',
    'Add a new column restriction' => '添加新的栏目限制',
    'Edit this role' => '编辑角色',
    'Remove this role' => '删除角色',
    'There is no restriction for this role.' => '当前角色无限制。',
    'Only moving task between those columns is permitted' => '只能在以下栏目间移动任务',
    'Close a task in a specific column when not moved during a given period' => '当指定栏目下的任务在指定时间内未移动时关闭任务',
    'Edit columns' => '编辑栏目',
    'The column restriction has been created successfully.' => '成功创建栏目限制。',
    'Unable to create this column restriction.' => '无法创建栏目限制。',
    'Column restriction removed successfully.' => '成功删除栏目限制。',
    'Unable to remove this restriction.' => '无法删除限制。',
    'Your custom project role has been created successfully.' => '自定义项目角色创建成功。',
    'Unable to create custom project role.' => '无法删除自定义项目角色。',
    'Your custom project role has been updated successfully.' => '自定义项目角色更新成功。',
    'Unable to update custom project role.' => '无法更新自定义项目角色。',
    'Custom project role removed successfully.' => '成功删除自定义项目角色。',
    'Unable to remove this project role.' => '无法删除项目角色。',
    'The project restriction has been created successfully.' => '成功创建项目限制。',
    'Unable to create this project restriction.' => '无法创建项目限制。',
    'Project restriction removed successfully.' => '成功删除项目限制。',
    'You cannot create tasks in this column.' => '你不能在此栏目下创建任务。',
    'Task creation is permitted for this column' => '当前栏目下允许创建任务。',
    'Closing or opening a task is permitted for this column' => '当前栏目下允许开关任务。',
    'Task creation is blocked for this column' => '当前栏目下禁止创建任务。',
    'Closing or opening a task is blocked for this column' => '禁止在此栏下开关任务',
    'Task creation is not permitted' => '不能创建任务',
    'Closing or opening a task is not permitted' => '禁止开关任务',
    'New drag and drop restriction for the role "%s"' => '为角色"%s"新建拖动限制',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => '此角色下的用户将只能在源栏目和目标栏目间移动任务。',
    'Remove a column restriction' => '移除栏目限制',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => '你真的要删除栏目限制："%s"到"%s"？',
    'New column restriction for the role "%s"' => '为角色"%s"增加栏目限制？',
    'Rule' => '规则',
    'Do you really want to remove this column restriction?' => '你真的要移除栏目限制？',
    'Custom roles' => '角色',
    'New custom project role' => '新建项目角色',
    'Edit custom project role' => '编辑项目角色',
    'Remove a custom role' => '删除自定义角色',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => '你真的要删除这个自定义橘色："%s"？当前角色下的用户将转换成普通项目成员。',
    'There is no custom role for this project.' => '当前项目没有自定义角色',
    'New project restriction for the role "%s"' => '给角色"%s"新建项目限制',
    'Restriction' => '限制',
    'Remove a project restriction' => '移除项目限制',
    'Do you really want to remove this project restriction: "%s"?' => '你真的要删除项目限制："%s"？',
    'Duplicate to multiple projects' => '复制到多个项目',
    'This field is required' => '此项必填',
    'Moving a task is not permitted' => '禁止移动任务',
    'This value must be in the range %d to %d' => '输入值必须在%d到%d之间',
    'You are not allowed to move this task.' => '你不能移动此任务',
    'API User Access' => 'API access',
    'Preview' => '预览',
    'Write' => '写入',
    'Write your text in Markdown' => '用markdown格式写入文本',
    'No personal API access token registered.' => '没有API access token 注册。',
    'Your personal API access token is "%s"' => '你的API access token 是 “%s”',
    'Remove your token' => '移除token',
    'Generate a new token' => '生成新的token',
    'Showing %d-%d of %d' => '本页显示 %d-%d 条，共有: %d 条',
    'Outgoing Emails' => '目标邮件',
    'Add or change currency rate' => '添加更改汇率',
    'Reference currency: %s' => '参考汇率：%s',
    'Add custom filters' => '添加过滤器',
    'Export' => '导出',
    'Add link label' => '添加链接标签',
    'Incompatible Plugins' => '不兼容插件',
    'Compatibility' => '兼容性',
    'Permissions and ownership' => '权限和所有者',
    'Priorities' => '属性',
    'Close this window' => '关闭窗口',
    'Unable to upload this file.' => '无法上传此文件。',
    'Import tasks' => '导入任务',
    'Choose a project' => '选择项目',
    'Profile' => '个人资料',
    'Application role' => '应用角色',
    '%d invitations were sent.' => '%d个邀请已发送。',
    '%d invitation was sent.' => '%d个邀请已发送。',
    'Unable to create this user.' => '无法创建该用户。',
    'Kanboard Invitation' => '看板邀请',
    'Visible on dashboard' => '控制面板可见',
    'Created at:' => '创建于：',
    'Updated at:' => '更新于：',
    'There is no custom filter.' => '当前没有自定义过滤。',
    'New User' => '新建用户',
    'Authentication' => '认证',
    'If checked, this user will use a third-party system for authentication.' => '选中时用户将启用第三方系统认证。',
    'The password is necessary only for local users.' => '只有本地用户才需要设置密码。',
    'You have been invited to register on Kanboard.' => '你被邀请注册看板。',
    'Click here to join your team' => '点击这里加入你的团队',
    'Invite people' => '邀请新用户',
    'Emails' => '邮件',
    'Enter one email address by line.' => '输入邮件地址，每行一个。',
    'Add these people to this project' => '添加用户到项目',
    'Add this person to this project' => '添加用户到项目',
    'Sign-up' => '注册',
    'Credentials' => '认证信息',
    'New user' => '新用户',
    'This username is already taken' => '该用户名已被占用',
    'Your profile must have a valid email address.' => '个人资料必须有一个有效email地址。',
    'TRL - Turkish Lira' => '土耳其里拉',
    'The project email is optional and could be used by several plugins.' => '项目邮件地址可选，适用于插件。',
    'The project email must be unique across all projects' => '项目邮件地址必须全局唯一',
    'The email configuration has been disabled by the administrator.' => '邮件配置被管理员禁用。',
    'Close this project' => '关闭项目',
    'Open this project' => '打开项目',
    'Close a project' => '关闭项目',
    'Do you really want to close this project: "%s"?' => '你真的要关闭项目："%s"？',
    'Reopen a project' => '重开项目',
    'Do you really want to reopen this project: "%s"?' => '你真的要重开项目："%s"？',
    'This project is open' => '项目已打开',
    'This project is closed' => '项目已关闭',
    'Unable to upload files, check the permissions of your data folder.' => '无法上传文件，请检查你的data目录权限。',
    'Another category with the same name exists in this project' => '该项目下同名分类已存在',
    'Comment sent by email successfully.' => '评论已通过邮件发送成功。',
    'Sent by email to "%s" (%s)' => '已发送邮件至"%s" (%s)',
    'Unable to read uploaded file.' => '无法读取上传文件。',
    'Database uploaded successfully.' => '数据库上传成功。',
    'Task sent by email successfully.' => '任务已通过邮件发送成功。',
    'There is no category in this project.' => '当前项目没有分类。',
    'Send by email' => '发送邮件',
    'Create and send a comment by email' => '通过电子邮件创建和发送评论',
    'Subject' => '主题',
    'Upload the database' => '上传数据库',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => '你可以上传先前下载的sqlite数据库(Gzip 格式)。',
    'Database file' => '数据库文件',
    'Upload' => '上传',
    'Your project must have at least one active swimlane.' => '项目必须包含至少一个活跃泳道。',
    'Project: %s' => '项目：%s',
    'Automatic action not found: "%s"' => '自动动作未找到："%s"',
    '%d projects' => '%d 项目',
    '%d project' => '%d 项目',
    'There is no project.' => '当前没有项目。',
    'Sort' => '排序',
    'Project ID' => '项目ID',
    'Project name' => '项目名',
    'Public' => '公开',
    'Personal' => '私有',
    '%d tasks' => '%d 任务',
    '%d task' => '%d 任务',
    'Task ID' => '任务ID',
    'Assign automatically a color when due date is expired' => '当任务过期时自动标注颜色',
    'Total score in this column across all swimlanes' => '该栏目所有泳道上的总分',
    'HRK - Kuna' => '克罗地亚库纳',
    'ARS - Argentine Peso' => '阿根廷比索',
    'COP - Colombian Peso' => '哥伦比亚比索',
    '%d groups' => '%d 用户组',
    '%d group' => '%d 用户组',
    'Group ID' => '用户组ID',
    'External ID' => '附属ID',
    '%d users' => '%d 用户',
    '%d user' => '%d 用户',
    'Hide subtasks' => '显示子任务',
    'Show subtasks' => '隐藏子任务',
    'Authentication Parameters' => '验证参数',
    'API Access' => 'API授权',
    'No users found.' => '未找到用户。',
    'User ID' => '用户ID',
    'Notifications are activated' => '通知已启用',
    'Notifications are disabled' => '通知已禁用',
    'User disabled' => '用户已禁用',
    '%d notifications' => '%d 通知',
    '%d notification' => '%d 通知',
    'There is no external integration installed.' => '当前没有外部整合安装。',
    'You are not allowed to update tasks assigned to someone else.' => '你没有权限更新任务指派。',
    'You are not allowed to change the assignee.' => '你没有权限更改当前受理人。',
    'Task suppression is not permitted' => '不允许抑制任务',
    'Changing assignee is not permitted' => '不允许更改受理人',
    'Update only assigned tasks is permitted' => '只允许更新已受理任务',
    'Only for tasks assigned to the current user' => '只作用于当前用户已受理任务',
    'My projects' => '我的项目',
    'You are not a member of any project.' => '你不是任何项目的成员。',
    'My subtasks' => '我的子任务',
    '%d subtasks' => '%d 子任务',
    '%d subtask' => '%d 子任务',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => '只允许在这些栏目间移动受理给当前用户的任务',
    '[DUPLICATE]' => '[重复]',
    'DKK - Danish Krona' => '丹麦克朗',
    'Remove user from group' => '从用户组中移除用户',
    'Assign the task to its creator' => '将任务分配给创建者',
    'This task was sent by email to "%s" with subject "%s".' => '任务已通过邮件发送给"%s"（标题："%s"）。',
    'Predefined Email Subjects' => '预定义的邮件主题',
    'Write one subject by line.' => '添加主题（每行）。',
    'Create another link' => '创建新链接',
    'BRL - Brazilian Real' => '巴西雷亚尔',
    'Add a new Kanboard task' => '添加新任务',
    'Subtask not started' => '子任务未开始',
    'Subtask currently in progress' => '子任务进行中',
    'Subtask completed' => '子任务已完成',
    'Subtask added successfully.' => '子任务添加成功。',
    '%d subtasks added successfully.' => '%d子任务添加成功。',
    'Enter one subtask by line.' => '添加子任务（每行）。',
    'Predefined Contents' => '预设内容',
    'Predefined contents' => '预设内容',
    'Predefined Task Description' => '预定义任务描述',
    'Do you really want to remove this template? "%s"' => '你真的要移除该模板？"%s"',
    'Add predefined task description' => '添加预定义任务描述',
    'Predefined Task Descriptions' => '预定义任务描述',
    'Template created successfully.' => '模板添加成功。',
    'Unable to create this template.' => '无法添加该模板。',
    'Template updated successfully.' => '模板更新成功。',
    'Unable to update this template.' => '无法更新此模板。',
    'Template removed successfully.' => '模板删除成功。',
    'Unable to remove this template.' => '无法删除该模板。',
    'Template for the task description' => '任务描述模板',
    'The start date is greater than the end date' => '开始日期晚于结束日期',
    'Tags must be separated by a comma' => '标签必须以逗号分割',
    'Only the task title is required' => '只有任务标题是必须的',
    'Creator Username' => '创建人',
    'Color Name' => '颜色名称',
    'Column Name' => '栏目名称',
    'Swimlane Name' => '泳道名称',
    'Time Estimated' => '预计耗时',
    'Time Spent' => '时间花费',
    'External Link' => '外部链接',
    'This feature enables the iCal feed, RSS feed and the public board view.' => '该功能将开启iCal订阅, RSS订阅以及公共查看权限。',
    'Stop the timer of all subtasks when moving a task to another column' => '当移动任务到别的栏目组时停止所有子任务计时器',
    'Subtask Title' => '子任务标题',
    'Add a subtask and activate the timer when moving a task to another column' => '当移动任务到别的栏目组时添加子任务并开始计时',
    'days' => '天',
    'minutes' => '分钟',
    'seconds' => '秒',
    'Assign automatically a color when preset start date is reached' => '当到达预设起始日期时自动指派颜色',
    'Move the task to another column once a predefined start date is reached' => '当到达预定起始日期时移动任务到另一栏目',
    'This task is now linked to the task %s with the relation "%s"' => '该任务与任务：%s 已建立"%s"关联',
    'The link with the relation "%s" to the task %s has been removed' => '该任务与任务：%s 已解除"%s"关联',
    'Custom Filter:' => '自定义过滤器：',
    'Unable to find this group.' => '无法找到该用户组。',
    '%s moved the task #%d to the column "%s"' => '%s将任务 #%d 移动到了 "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s将任务 #%d 移动到了 "%s" 的 %d',
    '%s moved the task #%d to the swimlane "%s"' => '%s将任务 #%d 移动到了泳道 "%s" 下',
    '%sh spent' => '花费%s小时',
    '%sh estimated' => '预估%s小时',
    'Select All' => '全选',
    'Unselect All' => '取消',
    'Apply action' => '应用动作',
    'Move selected tasks to another column or swimlane' => '移动选中任务到另一列',
    'Edit tasks in bulk' => '批量编辑任务',
    'Choose the properties that you would like to change for the selected tasks.' => '选择你想要批量编辑的任务属性。',
    'Configure this project' => '项目配置',
    'Start now' => '立即开始',
    '%s removed a file from the task #%d' => '%s 从任务 #%d 删除了文件',
    'Attachment removed from task #%d: %s' => '附件已从任务 #%d: %s 中删除',
    'No color' => '未标色',
    'Attachment removed "%s"' => '附件已删除 "%s"',
    '%s removed a file from the task %s' => '%s 从任务 %s 中删除了文件',
    'Move the task to another swimlane when assigned to a user' => '将分配给用户的任务移动到另一个泳道',
    'Destination swimlane' => '目标泳道',
    'Assign a category when the task is moved to a specific swimlane' => '将移动到指定泳道的任务设定分类',
    'Move the task to another swimlane when the category is changed' => '当分类改变时将任务移动到另一个泳道',
    'Reorder this column by priority (ASC)' => '按优先级重排(升序)',
    'Reorder this column by priority (DESC)' => '按优先级重排(降序)',
    'Reorder this column by assignee and priority (ASC)' => '按指派和优先级重排(升序)',
    'Reorder this column by assignee and priority (DESC)' => '按指派和优先级重排(降序)',
    'Reorder this column by assignee (A-Z)' => '按指派重排(A-Z)',
    'Reorder this column by assignee (Z-A)' => '按指派重排(Z-A)',
    'Reorder this column by due date (ASC)' => '按逾期时间重排(升序)',
    'Reorder this column by due date (DESC)' => '按逾期时间重排(降序)',
    // 'Reorder this column by id (ASC)' => '',
    // 'Reorder this column by id (DESC)' => '',
    '%s moved the task #%d "%s" to the project "%s"' => '%s 已将任务 #%d "%s" 移动到项目"%s" ',
    'Task #%d "%s" has been moved to the project "%s"' => '任务 #%d "%s" 已被移动到项目 "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => '当任务即将在指定天数内超期时移动到另一栏',
    'Automatically update the start date when the task is moved away from a specific column' => '当任务离开指定栏目时自动更新开始时间',
    'HTTP Client:' => 'HTTP客户端',
    'Assigned' => '已分配',
    'Task limits apply to each swimlane individually' => '任务限制分别应用于每个泳道',
    'Column task limits apply to each swimlane individually' => '列任务限制分别应用于每个泳道',
    'Column task limits are applied to each swimlane individually' => '列任务限制已经被分别应用于每个泳道',
    'Column task limits are applied across swimlanes' => '列任务限制已经被跨泳道应用',
    'Task limit: ' => '任务限制',
    'Change to global tag' => '更改为全局标签',
    'Do you really want to make the tag "%s" global?' => '您是否真的想将标签 "%s" 设置为全局标签？',
    'Enable global tags for this project' => '为该项目启用全局标签',
    'Group membership(s):' => '群组成员：',
    '%s is a member of the following group(s): %s' => '%s 是以下组的成员： %s',
    '%d/%d group(s) shown' => '%d/%d 个组已显示',
    'Subtask creation or modification' => '子任务创建或修改',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => '将任务移至特定泳道时，将任务分配给指定用户',
    'Comment' => '评论',
    'Collapse vertically' => '栏内滚动',
    'Expand vertically' => '全屏滚动',
    'MXN - Mexican Peso' => '墨西哥比索',
    'Estimated vs actual time per column' => '每栏目预计和实际耗时',
    'HUF - Hungarian Forint' => '匈牙利 - 福林',
    'XBT - Bitcoin' => 'XBT - 比特币',
    'You must select a file to upload as your avatar!' => '你必须选择一张图片作为你的头像',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '你所上传的文件不是有效图像！(只有*.gif, *.jpg, *.jpeg and *.png才被允许！)',
    'Automatically set the due date when the task is moved away from a specific column' => '当任务离开指定栏目时自动设置到期时间',
    'No other projects found.' => '未找到其它项目。',
    'Please choose a project you want to copy the tasks from.' => '请选择将要复制的任务所属的项目。',
    'Import Tasks' => '引入任务',
    'Copy' => '复制',
    'Tasks copied successfully.' => '任务复制成功。',
    'Unable to copy tasks.' => '无法复制任务。',
    // 'Theme' => '',
    // 'Theme:' => '',
    // 'Light theme' => '',
    // 'Dark theme' => '',
    // 'Automatic theme - Sync with system' => '',
    // 'Application managers or more' => '',
    // 'Administrators' => '',
    // 'Visibility:' => '',
    // 'Standard users' => '',
    // 'Visibility is required' => '',
    // 'The visibility should be an app role' => '',
    // 'Reply' => '',
    // '%s wrote: ' => '',
    // 'Number of visible tasks in this column and swimlane' => '',
    // 'Number of tasks in this swimlane' => '',
    // 'Unable to find another subtask in progress, you can close this window.' => '',
    // 'This theme is invalid' => '',
    // 'This role is invalid' => '',
    // 'This timezone is invalid' => '',
    // 'This language is invalid' => '',
    // 'This URL is invalid' => '',
    // 'Date format invalid' => '',
    // 'Time format invalid' => '',
    // 'Invalid Mail transport' => '',
    // 'Color invalid' => '',
    // 'This value must be greater or equal to %d' => '',
    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
    // 'Just add these tag(s)' => '',
    // 'Remove internal link(s)' => '',
);
